# Teneto

[![Documentation Status](https://readthedocs.org/projects/teneto/badge/?version=latest)](http://teneto.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/teneto.svg)](https://badge.fury.io/py/teneto)
[![Build Status](https://travis-ci.org/wiheto/teneto.svg?branch=master)](https://travis-ci.org/wiheto/teneto)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/5e492e68a0c841b6a7118b91f0ad2716)](https://www.codacy.com/app/wiheto/teneto?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=wiheto/teneto&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/wiheto/teneto/badge.svg?branch=master)](https://coveralls.io/github/wiheto/teneto?branch=master)
[![DOI](https://zenodo.org/badge/61498436.svg)](https://zenodo.org/badge/latestdoi/61498436)

**Te**mporal **ne**twork **to**ols. Version 0.4.4

## What is the package

Package includes various tools for analyzing temporal network data. Temporal network measures, temporal network generation, derivation of time-varying/dynamic connectivities, plotting functions. 

Some extra focus is placed on neuroimaging data (e.g. compatible with BIDS - _NB: currently not compliant with latest release candidate of BIDS Derivatives_).

## Installation

With pip installed:

`pip install teneto`

to upgrade teneto:

`pip install teneto -U`

Requires: Python 3.5 or python 3.6. 

Installing teneto via pip installs all python package requirements as well. 

## Documentation

More detailed documentation can be found at  [teneto.readthedocs.io](https://teneto.readthedocs.io) and includes tutorials.

## Outlook

This package is under active development. And a lot of changes will still be made.

## Contributers

For a list of contributers to teneto, see:  [teneto.readthedocs.io](https://teneto.readthedocs.io/en/latest/contribute.html)

## Cite

If using this, please cite us. At present we do not have a dedicated article about teneto, but you can cite the software using the [Zenendo DOI](https://doi.org/10.5281/zenodo.2535993) and/or the article where teneto is introduced, along with a considerable discussion about many of the measures in teneto:

Thompson et al (2017) "From static to temporal network theory applications to functional brain connectivity." _Network Neuroscience_, 2: 1. p.69-99  [Link](https://www.mitpressjournals.org/doi/abs/10.1162/NETN_a_00011)
